==> sympa_6.2.60~dfsg.orig.tar.xz: sympa-6.2.60/CONTRIBUTING.md <==
Contributing to Sympa
=====================

Please report bugs, suggest new features, translate user interface to your language, or enhance documentation, if you want to help the sympa community to deliver a more reliable version of Sympa.

How to report bugs / send patches
---------------------------------

We expect feedback by users and developers.  You can submit issues and pull requests to the project on GitHub:

  - [sympa project on GitHub](https://github.com/sympa-community/sympa)

If you have difficulty accessing GitHub site, you may send bug reports to the developers:

  - [sympa-developpers mailing list](https://listes.renater.fr/sympa/info/sympa-developpers)

    Note that your message will be open to the public.

How to translate user interface
-------------------------------

You may help us translating user interface of Sympa to your languages:

  * [Translate Sympa](https://translate.sympa.org/)

To add or correct translations, you have to sign up.

More about translation, please see the [Translation Guide](https://translate.sympa.org/pages/help).

Incubating new documentation
-------------------------------

The site for development of Sympa documentation launced:

  * [Incubating the new Sympa documentation site](https://github.com/sympa-community/sympa-community.github.io)

This site aims to renovate Sympa documentation.  We expect inputs including addition, correction and suggestion from the community.  For further details, please see the page "[Contributing for Sympa documentation](https://github.com/sympa-community/sympa-community.github.io/blob/master/CONTRIBUTING.md)".

----
[The Sympa Community](https://github.com/sympa-community)

==> sympa_6.2.70~dfsg.orig.tar.xz: sympa-6.2.70~dfsg/CONTRIBUTING.md <==
Contributing to Sympa
=====================

Please report bugs, suggest new features, translate user interface to your language, or enhance documentation, if you want to help the sympa community to deliver a more reliable version of Sympa.

How to report bugs / send patches
---------------------------------

We expect feedback by users and developers.  You can submit issues and pull requests to the project on GitHub:

  - [sympa project on GitHub](https://github.com/sympa-community/sympa)

If you have difficulty accessing GitHub site, you may send bug reports to the developers:

  - [devel@sympa mailing list](https://lists.sympa.community/info/devel)

    Note that your message will be open to the public.

How to translate user interface
-------------------------------

You may help us translating user interface of Sympa to your languages:

  * [Translate Sympa](https://translate.sympa.community/)

To add or correct translations, you have to sign up.

More about translation, please see the [Translation Guide](https://translate.sympa.community/pages/help).

Incubating new documentation
-------------------------------

The site for development of Sympa documentation launced:

  * [Incubating the new Sympa documentation site](https://github.com/sympa-community/sympa-community.github.io)

This site aims to renovate Sympa documentation.  We expect inputs including addition, correction and suggestion from the community.  For further details, please see the page "[Contributing for Sympa documentation](https://www.sympa.community/CONTRIBUTING.html)".

----
[The Sympa Community](https://github.com/sympa-community)
